Learn R Programming

causalDT (version 1.0.0)

get_party_node_depths: Get depth of each node in a party model.

Description

Get depth of each node in a party model.

Usage

get_party_node_depths(party_fit, return_features = FALSE)

Arguments

party_fit

A party object.

return_features

Logical indicating whether to return the feature associated with each node.