Learn R Programming

causalDT (version 1.0.0)

get_rpart_paths: Get decision paths from an rpart model.

Description

Return the decision paths for each leaf node in an rpart model as character strings.

Usage

get_rpart_paths(rpart_fit)

Value

A list of character vectors, where each element corresponds to the decision path for a leaf node in the rpart_fit model.

Arguments

rpart_fit

An rpart object.