Return the split information for each node in an rpart model as a data frame.
get_rpart_tree_info(rpart_fit, X = NULL, digits = getOption("digits"))A data.frame with information regarding the feature/threshold used
for each split in the rpart model.
An rpart object.
Optional data frame containing the features used in the rpart
model. Only used if the model contains categorical variables.
Number of digits to round the split values to.